FROM ubuntu:20.04

# Add needle tools
RUN apt update
RUN apt full-upgrade -y
RUN apt install -y build-essential curl python3 git git-lfs
# RUN apt install -y build-essential curl python3 git git-lfs sudo

RUN ln -s /usr/bin/python3 /usr/bin/python

# Add groups and user
RUN groupadd -g 105 render
RUN useradd --create-home -G render,video --shell /bin/bash jenkins
# RUN echo "jenkins ALL=(ALL:ALL) NOPASSWD: ALL" | sudo tee /etc/sudoers.d/jenkins

# Add repo
RUN curl https://storage.googleapis.com/git-repo-downloads/repo > /usr/bin/repo
RUN chmod a+x /usr/bin/repo

USER jenkins
WORKDIR /home/jenkins

# Clone ROCm using repo
RUN mkdir -p /home/jenkins/ROCm/
WORKDIR /home/jenkins/ROCm/
RUN repo init -u https://github.com/RadeonOpenCompute/ROCm.git -b roc-5.4.x
RUN repo sync

# Get needle version of cmake
WORKDIR /home/jenkins/
RUN curl https://cmake.org/files/v3.18/cmake-3.18.6-Linux-x86_64.tar.gz | tar xz

# Clone script to build ROCm
WORKDIR /home/jenkins/
RUN git clone https://github.com/xuhuisheng/rocm-build.git
WORKDIR /home/jenkins/rocm-build
RUN chmod a+x /home/jenkins/rocm-build/*.sh
RUN chmod a+x /home/jenkins/rocm-build/navi14/*.sh
RUN sed -i "s@sudo @@g" /home/jenkins/rocm-build/install-dependency.sh
RUN git checkout 59b87dc62972c1ad32a8862e9ea6b5921c1f33a0

# Set correct environments
ENV ROCM_INSTALL_DIR=/opt/rocm
ENV ROCM_MAJOR_VERSION=5
ENV ROCM_MINOR_VERSION=4
ENV ROCM_PATCH_VERSION=0
ENV ROCM_LIBPATCH_VERSION=50400
ENV CPACK_DEBIAN_PACKAGE_RELEASE=72~20.04
ENV ROCM_PKGTYPE=DEB
ENV ROCM_GIT_DIR=/home/jenkins/ROCm
ENV ROCM_BUILD_DIR=/home/jenkins/rocm-build/build
ENV ROCM_PATCH_DIR=/home/jenkins/rocm-build/patch
ENV AMDGPU_TARGETS="gfx1012"
ENV CMAKE_DIR=/home/jenkins/cmake-3.18.6-Linux-x86_64
ENV PATH=$ROCM_INSTALL_DIR/bin:$ROCM_INSTALL_DIR/llvm/bin:$ROCM_INSTALL_DIR/hip/bin:$CMAKE_DIR/bin:$PATH

USER root

# Install dependencies
RUN DEBIAN_FRONTEND=noninteractive TZ=Etc/UTC /home/jenkins/rocm-build/install-dependency.sh

# Install rocm-dev packages that already have partial support
RUN mkdir --parents --mode=0755 /etc/apt/keyrings
RUN curl https://repo.radeon.com/rocm/rocm.gpg.key | gpg --dearmor | tee /etc/apt/keyrings/rocm.gpg > /dev/null
RUN echo 'deb [arch=amd64 signed-by=/etc/apt/keyrings/rocm.gpg] https://repo.radeon.com/rocm/apt/5.4.3 focal main' | tee /etc/apt/sources.list.d/rocm.list
RUN apt update
RUN apt install -y rocm-dev

# Remove !!!
RUN apt install -y sudo
RUN echo "jenkins ALL=(ALL:ALL) NOPASSWD: ALL" | sudo tee /etc/sudoers.d/jenkins

USER jenkins

# Build ROCm components
RUN /home/jenkins/rocm-build/navi14/22.rocblas.sh
RUN /home/jenkins/rocm-build/21.rocfft.sh
# RUN /home/jenkins/rocm-build/navi14/22.rocblas.sh
RUN /home/jenkins/rocm-build/24.rocrand.sh

RUN sudo apt install -y rocprim
COPY ./25.rocsparse-gfx10-1.patch /home/jenkins/rocm-build/patch/25.rocsparse-gfx10-1.patch
RUN /home/jenkins/rocm-build/navi14/25.rocsparse.sh
RUN /home/jenkins/rocm-build/28.rccl.sh

# # Clone PyTorch
# RUN git clone https://github.com/pytorch/pytorch.git
# WORKDIR /home/jenkins/pytorch
# RUN git submodule sync
# RUN git submodule update --init --recursive

# # Build PyTorch
# ENV PYTORCH_ROCM_ARCH=gfx1012
# RUN export PYTORCH_ROCM_ARCH=gfx1012
# RUN python3 tools/amd_build/build_amd.py
# ENV USE_ROCM=1
# RUN USE_ROCM=1 python3 setup.py install --user

# # Clone PyTorch Vision
# WORKDIR /home/jenkins
# RUN git clone https://github.com/pytorch/vision.git
# WORKDIR /home/jenkins/vision
# RUN python3 setup.py install --user

# # Build PyTorch Vision
# WORKDIR /home/jenkins/
# RUN git clone https://github.com/pytorch/examples.git
# WORKDIR /home/jenkins/examples

# # Run Mnist test
# ENTRYPOINT [ "python", "mnist/main.py" ]
ENTRYPOINT [ "tail", "-f", "/dev/null" ]
